Crate zesh_git

Crate zesh_git 

Structs

MockGit
A mocked implementation of the Git trait for testing purposes.
RealGit
A real implementation of the Git trait that calls the actual git commands.

Enums

GitError

Traits

Git
A trait representing Git operations.