Crate zesh_git
zesh_
git
0.1.1
All Items
Crate Items
Structs
Enums
Traits
Crate
zesh_
git
Structs

MockGit
A mocked implementation of the Git trait for testing purposes.
RealGit
A real implementation of the Git trait that calls the actual git commands.
Enums

GitError
Traits

Git
A trait representing Git operations.